@@ -86,12 +86,14 @@ typedef struct getdns_upstream {
 	struct sockaddr_storage  addr;
 
 	/* How is this upstream doing? */
+	size_t                   writes_done;
+	size_t                   responses_received;
 	int                      to_retry;
 	int                      back_off;
 
 	/* For sharing a TCP socket to this upstream */
 	int                      fd;
-	getdns_base_transport_t  dns_base_transport;
+	getdns_transport_list_t  transport;
 	SSL*                     tls_obj;
 	getdns_tls_hs_state_t    tls_hs_state;
 	getdns_dns_req *         starttls_req;
@@ -131,17 +133,21 @@ struct getdns_context {
 	getdns_namespace_t   *namespaces;
 	int                  namespace_count;
 	uint64_t             timeout;
+	uint64_t             idle_timeout;
 	getdns_redirects_t   follow_redirects;
 	struct getdns_list   *dns_root_servers;
 	getdns_append_name_t append_name;
 	struct getdns_list   *suffix;
-	struct getdns_list   *dnssec_trust_anchors;
+	uint8_t              *trust_anchors;
+	size_t                trust_anchors_len;
 	getdns_upstreams     *upstreams;
-	getdns_transport_t   dns_transport;
-	getdns_base_transport_t dns_base_transports[GETDNS_BASE_TRANSPORT_MAX];
 	uint16_t             limit_outstanding_queries;
 	uint32_t             dnssec_allowed_skew;
 
+	getdns_transport_list_t   *dns_transports;
+	size_t                     dns_transport_count;
+	size_t                     dns_transport_current;
+
 	uint8_t edns_extended_rcode;
 	uint8_t edns_version;
 	uint8_t edns_do_bit;
@@ -160,10 +166,11 @@ struct getdns_context {
 
 	/* The underlying contexts that do the real work */
 	struct ub_ctx *unbound_ctx;
+	int            unbound_ta_set;
 
 	/* A tree to hold local host information*/
 	getdns_rbtree_t local_hosts;
-	int has_ta; /* No DNSSEC without trust anchor */
+
 	int return_dnssec_status;
 
 	/* which resolution type the contexts are configured for
@@ -189,6 +196,8 @@ struct getdns_context {
 	struct filechg *fchg_resolvconf;
 	struct filechg *fchg_hosts;
 
+	uint8_t trust_anchors_spc[1024];
+
 }; /* getdns_context */
 
 /** internal functions **/
@@ -234,9 +243,8 @@ int filechg_check(struct getdns_context *context, struct filechg *fchg);
 
 void priv_getdns_context_ub_read_cb(void *userarg);
 
-getdns_return_t priv_set_base_dns_transports(getdns_base_transport_t *,
-    getdns_transport_t);
-
 void priv_getdns_upstreams_dereference(getdns_upstreams *upstreams);
 
+void priv_getdns_upstream_shutdown(getdns_upstream *upstreams);
+
 #endif /* _GETDNS_CONTEXT_H_ */
