@@ -499,13 +499,19 @@ getdns_indent(size_t indent)
 }				/* getdns_indent */
 
 static int
-priv_getdns_bindata_is_dname(struct getdns_bindata *bindata)
+priv_getdns_bindata_is_dname(getdns_bindata *bindata)
 {
 	size_t i = 0, n_labels = 0;
-	while (i < bindata->size) {
+
+	while (i < bindata->size && bindata->data[i]) {
 		i += ((size_t)bindata->data[i]) + 1;
 		n_labels++;
 	}
+	if (i < bindata->size && !bindata->data[i]) {
+		n_labels++;
+		i++;
+	}
+
 	return i == bindata->size && n_labels > 1 &&
 		bindata->data[bindata->size - 1] == 0;
 }
@@ -608,14 +614,14 @@ static const char *unknown_str_l[] = {" <unknown>", " null", "null"};
  * @param buf    buffer to write to
  * @param indent number of spaces to append after newline
  * @param list   the to list print
- * @param for_namespaces The list is a list of namespace literals.
+ * @param for_literals The list is a list of literals.
  *               Show the literal instead of the value.
  * @return       on success the number of written characters
  *               if an output error is encountered, a negative value
  */
 static int
 getdns_pp_list(gldns_buffer *buf, size_t indent, const getdns_list *list,
-    int for_namespaces, int json)
+    int for_literals, int json)
 {
 	size_t i, length, p = gldns_buffer_position(buf);
 	getdns_data_type dtype;
@@ -651,7 +657,7 @@ getdns_pp_list(gldns_buffer *buf, size_t indent, const getdns_list *list,
 
 			if (getdns_list_get_int(list, i, &int_item))
 				return -1;
-			if (!json && for_namespaces &&
+			if (!json && for_literals &&
 			    (strval =
 			     priv_getdns_get_const_info(int_item)->name)) {
 				if (gldns_buffer_printf(buf, "%s", strval) < 0)
@@ -829,7 +835,6 @@ getdns_pp_dict(gldns_buffer * buf, size_t indent,
 			     strcmp(item->node.key, "dnssec_status") == 0 ||
 			     strcmp(item->node.key, "status") == 0 ||
 			     strcmp(item->node.key, "append_name") == 0 ||
-			     strcmp(item->node.key, "dns_transport") == 0 ||
 			     strcmp(item->node.key, "follow_redirects") == 0 ||
 			     strcmp(item->node.key, "resolution_type") == 0) &&
 			    (strval =
@@ -893,7 +898,8 @@ getdns_pp_dict(gldns_buffer * buf, size_t indent,
 			    getdns_indent(indent)) < 0)
 				return -1;
 			if (getdns_pp_list(buf, indent, item->data.list, 
-			    (strcmp(item->node.key, "namespaces") == 0),
+			    (strcmp(item->node.key, "namespaces") == 0 ||
+			     strcmp(item->node.key, "dns_transport_list") == 0),
 			    json) < 0)
 				return -1;
 			break;
