@@ -39,12 +39,14 @@
 #define DNSSEC_H_
 
 #include "getdns/getdns.h"
+#include "config.h"
+#include "gldns/gbuffer.h"
 #include "types-internal.h"
 
 /* Do some additional requests to fetch the complete validation chain */
 void priv_getdns_get_validation_chain(getdns_dns_req *dns_req);
 
-int priv_getdns_parse_ta_file(time_t *ta_mtime, getdns_list *ta_rrs);
+uint16_t _getdns_parse_ta_file(time_t *ta_mtime, gldns_buffer *gbuf);
 
 #endif
 
